
from formant.sdk.cloud.v2.formant_admin_api_client.models import TeleopSessionRecord, EventQueryEventTypesItem, EventTriggerCommand, AnnotationTags, AnnotationStreamType, SystemEventMetadata, CommentMetadata, Label, DatapointEventTags, CommandDeliveryEventTags, AnnotationMetadata, CommandDeliveryEventType, DatapointEventMetadata, StatefulEventTags, Comment, CommentTags, InterventionRequestSeverity, CustomEvent, PhysicalRequestData, SystemEventTags, TeleopSessionRecordType, LabelingRequestData, EventQuery, EventFilterTypesItem, AnnotationType, EventSort, DeviceOfflineEvent, DeviceOnlineEventMetadata, EventHistogramEntry, TaskSummaryReport, EventSeekQueryDirection, InterventionRequest, EventCounts, EventSortOrder, CustomEventMetadata, EventSeekQueryTypesItem, DeviceOfflineEventTags, InterventionRequestStreamType, EventQueryTypesItem, TeleopSessionRecordMetadata, StatefulEventType, PortForwardingSessionRecordTags, StatefulEventMetadata, CustomEventStreamType, InterventionRequestType, CustomEventType, SelectionRequestData, TaskSummaryType, EventSeekQueryEventTypesItem, TaskSummaryMetadata, DatapointEventType, EventExportSheetResult, EventListResponse, EventFilterSeveritiesItem, Annotation, SystemEventStreamType, CustomEventTags, DeviceOnlineEvent, DeviceOnlineEventType, DeviceOnlineEventTags, TaskSummary, EventFilterEventTypesItem, InterventionRequestTags, TaskSummaryStreamType, DeviceOfflineEventMetadata, SystemEvent, EventHistogram, SystemEventType, DeviceOfflineEventStreamType, StatefulEventStreamType, PortForwardingSessionRecordStreamType, CommentStreamType, TeleopRequestData, DeviceOnlineEventSeverity, EventSeekQuery, EventSeekQuerySeveritiesItem, TeleopSessionRecordTags, StatefulEventSeverity, DatapointEventStreamType, CommandDeliveryEventMetadata, CustomEventSeverity, EventExportSheetRequest, InterventionRequestInterventionType, DatapointEventSeverity, EventFilter, CommandDeliveryEventStreamType, PortForwardingSessionRecordMetadata, PortForwardingSessionRecordType, DeviceOnlineEventStreamType, EventSortColumn, InterventionRequestMetadata, EventQuerySeveritiesItem, LabeledPolygon, CommandDeliveryEvent, StatefulEvent, TeleopSessionRecordStreamType, DeviceOfflineEventType, TaskSummaryTags, CommentType, DatapointEvent, DeviceOfflineEventSeverity, PortForwardingSessionRecord
from formant.sdk.cloud.v2.formant_admin_api_client.api.event import event_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *




from formant.sdk.cloud.v2.formant_admin_api_client.models import Annotation, UserParametersRolesItem, SheetParameters, ScopeFilterTypesItem, AnnotationTags, AnnotationStreamType, AnnotationFieldValuesRequestTags, AnnotationFieldType, AnnotationField, AnnotationFieldValuesResponse, AnnotationMetadata, UserParameters, ScopeFilter, AnnotationFieldValuesRequest, AnnotationTemplate, AnnotationFieldValueTags, AnnotationTemplateTags, AnnotationFieldValue, AnnotationType, TagParameters, AnnotationTemplateListResponse
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation import annotation_controller_post
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation_template import annotation_template_controller_list, annotation_template_controller_get_one
from formant.sdk.cloud.v2.formant_admin_api_client.types import *




from formant.sdk.cloud.v2.formant_query_api_client.models import Battery, QueryTypesItem, BoundingBox, Path, File, Query, StreamDataType, StreamDataPointsItem, Map, StreamAggregateDataType, NumericSetEntry, Health, StreamDataListResponse, HealthStatus, Video, StreamData, VideoMimeType, Vector3, TransformNode, QueryAggregate, Odometry, Twist, Image, PointCloud, StreamAggregateDataTags, Video,VideoMimeType, Localization, Health,HealthStatus, ImageAnnotation, Transform, Goal, Location, Quaternion, StreamDataTags, StreamAggregateData, Bitset
from formant.sdk.cloud.v2.formant_query_api_client.api.query import query_controller_query
from formant.sdk.cloud.v2.formant_query_api_client.types import *



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="GoogleAuthRequest")


@attr.s(auto_attribs=True)
class GoogleAuthRequest:
    """
    Attributes:
        code (str):
        redirect_uri (str):
    """

    code: str
    redirect_uri: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        code = self.code
        redirect_uri = self.redirect_uri

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "code": code,
                "redirectUri": redirect_uri,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        code = d.pop("code")

        redirect_uri = d.pop("redirectUri")

        google_auth_request = cls(
            code=code,
            redirect_uri=redirect_uri,
        )

        google_auth_request.additional_properties = d
        return google_auth_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import ViewListResponse, ImageViewConfigurationMode, LocationViewport, LocalizationViewConfiguration, PartialViewLayoutType, ViewConfigurationType, Camera, View, PointCloudViewConfiguration, BitsetViewConfiguration, ViewLayoutType, ImageViewConfiguration, Filter, Vector3, NumericViewConfiguration, PartialViewTags, LocationViewConfigurationBasemap, PartialView, TransformTreeViewConfiguration, LocationViewConfiguration, ViewConfiguration, Location, ViewTags
from formant.sdk.cloud.v2.formant_admin_api_client.api.view import view_controller_get_one, view_controller_get_all, view_controller_patch
from formant.sdk.cloud.v2.formant_admin_api_client.types import *




from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceStreamConfiguration, DeviceConfigurationDocument, DeviceStreamRosTopicConfigurationType, DeviceQuery, DeviceStreamFileTailConfigurationType, DeviceStreamConfigurationQuality, TeleopJoystickAxisConfigurationDimension, ScopeFilterTypesItem, DeviceStreamHardwareConfigurationQuality, DeviceTeleopCustomStreamConfigurationNumericControlVisualization, VideoDevice, TeleopJoystickConfigurationPosition, DeviceState, DeviceStreamFileTailConfiguration, TeleopJoystickAxisConfiguration, DeviceTeleopRosStreamConfigurationQuality, OnDemandPresenceTimeRange, ScopeFilter, DeviceTelemetryConfiguration, Network, DeviceDiagnosticsConfiguration, NetworkInfo, CommandProgress, AdapterConfiguration, TeleopJoystickConfiguration, DeviceStreamCustomConfigurationType, DeviceTeleopConfiguration, TeleopViewConfiguration, DeviceOfflineEvent, Device, DeviceTeleopHardwareStreamConfigurationHardwareType, DeviceOnlineEventMetadata, DeviceApplicationConfigurationConfigurationMap, DeviceStreamDirectoryWatchConfiguration, OnDemandBufferBufferType, DeviceResourcesConfiguration, DeviceStreamHardwareConfigurationType, DeviceOfflineEventTags, DeviceDiskConfiguration, RtcInfoRtcIceTransportPoliciesItem, DeviceTeleopHardwareStreamConfiguration, DeviceStreamRosTopicConfiguration, ValidationConfiguration, DeviceReportedConfigurationState, PartialDevice, RosTopic, DeviceRosState, DeviceStateEnv, OnDemandBuffer, DeviceBlobData, DeviceTeleopRosStreamConfigurationAudioCodec, DeviceTeleopHardwareStreamConfigurationMode, DeviceFollower, DeviceQueryType, DeviceStreamRosLocalizationConfigurationType, DeviceConfigurationTemplateTags, DeviceOnlineEvent, DeviceDetailsListResponse, DeviceApplicationConfiguration, DeviceOnlineEventType, OsInfo, DeviceOnlineEventTags, DeviceStreamCustomConfiguration, OnDemandPresenceStreamItemGroupDatapointType, DeviceOfflineEventMetadata, DeviceStreamDirectoryWatchConfigurationFileType, DevicePortForwardingConfiguration, OnDemandStreamPresence, NodeInfo, DeviceOfflineEventStreamType, DeviceTeleopRosStreamConfigurationMode, KernelInfo, DeviceTeleopHardwareStreamConfigurationQuality, DeviceConfigurationTemplateListResponse, OnvifDevice, DeviceStreamConfigurationTags, DeviceTeleopRosStreamConfigurationTopicType, DeviceOnlineEventSeverity, DeviceScope, DeviceStreamHardwareConfigurationHardwareType, DeviceScopeTypesItem, DeviceTags, DeviceTeleopCustomStreamConfigurationRtcStreamType, DeviceCredentials, DeviceConfigurationTemplate, HwInfo, AudioDevice, DeviceType, DeviceRosConfiguration, PartialDeviceType, RtcInfo, OnDemandPresenceStreamItemGroup, DeviceStreamRosTransformTreeConfiguration, DeviceDetailsTags, DeviceStreamRosLocalizationConfiguration, PartialDeviceTags, DeviceTeleopCustomStreamConfigurationMode, OnDemandState, DeviceOnlineEventStreamType, DeviceConfigurationDocumentTags, RtcInfoRtcIceServerProtocol, DeviceStreamRosTransformTreeConfigurationType, DeviceTeleopCustomStreamConfiguration, DeviceStreamHardwareConfiguration, DeviceDetailsType, DeviceConfiguration, DeviceProvisioningRequest, DeviceTeleopHardwareStreamConfigurationRtcStreamType, DeviceProvisioning, DeviceStreamTransformConfiguration, DeviceStreamFileTailConfigurationFileFormat, DeviceTeleopRosStreamConfigurationNumericControlVisualization, DeviceTeleopCustomStreamConfigurationQuality, DeviceOfflineEventType, DeviceListResponse, DeviceStreamDirectoryWatchConfigurationType, DeviceTeleopRosStreamConfiguration, DeviceOfflineEventSeverity, DeviceDetails
from formant.sdk.cloud.v2.formant_admin_api_client.api.device import device_controller_query, device_controller_patch, device_controller_get_one, device_controller_get_configuration, device_controller_post_configuration
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from formant.sdk.cloud.v2.formant_admin_api_client.types import Optional




from formant.sdk.cloud.v2.formant_admin_api_client.models import CommandListResponse, CommandRequest, CommandQuery, FileInfo, CommandRequestListResponse, CommandTemplate, CommandStreamType, CommandDeliveryEventMetadata, ScopeFilterTypesItem, CommandDeliveryEventStreamType, CommandParameter, CommandDeliveryEventTags, CommandDeliveryEventType, ScopeFilter, Command, CommandDeliveryEvent, CommandParameterMeta, CommandProgress, CommandTemplateParameterMeta, CommandResponseTags, CommandTemplateTags, CommandTags, CommandTemplateListResponse, CommandResponseStreamType, CommandResponse
from formant.sdk.cloud.v2.formant_admin_api_client.api.command import command_controller_post, command_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
